==========
User guide
==========

Here you can find information on how to use Pharmpy in Python and R as well as from the command line. This guide covers
basic use cases in Pharmpy. More detailed information can be found in the API reference.

.. toctree::
   :maxdepth: 2

   model
   data
   modeling
   modelfit
   tools
   plots
   nonmem_plugin
   cli
   configuration
   using_r
